@@ -27,6 +27,7 @@ class TreeQuerySet(models.QuerySet):
         """
         if tree_fields:
             self.query.__class__ = TreeQuery
+            self.query._setup_query()
         else:
             self.query.__class__ = Query
         return self
@@ -45,10 +46,44 @@ class TreeQuerySet(models.QuerySet):
         to order tree siblings by those model fields
         """
         self.query.__class__ = TreeQuery
+        self.query._setup_query()
         self.query.sibling_order = order_by
         return self
 
-    def as_manager(cls, *, with_tree_fields=False):  # noqa: N805
+    def tree_filter(self, *args, **kwargs):
+        """
+        Adds a filter to the TreeQuery rank_table_query
+
+        Takes the same arguements as a Django QuerySet .filter()
+        """
+        self.query.__class__ = TreeQuery
+        self.query._setup_query()
+        self.query.rank_table_query = self.query.rank_table_query.filter(
+            *args, **kwargs
+        )
+        return self
+
+    def tree_exclude(self, *args, **kwargs):
+        """
+        Adds a filter to the TreeQuery rank_table_query
+
+        Takes the same arguements as a Django QuerySet .exclude()
+        """
+        self.query.__class__ = TreeQuery
+        self.query._setup_query()
+        self.query.rank_table_query = self.query.rank_table_query.exclude(
+            *args, **kwargs
+        )
+        return self
+
+    def tree_fields(self, **tree_fields):
+        self.query.__class__ = TreeQuery
+        self.query._setup_query()
+        self.query.tree_fields = tree_fields
+        return self
+
+    @classmethod
+    def as_manager(cls, *, with_tree_fields=False):
         manager_class = TreeManager.from_queryset(cls)
         # Only used in deconstruct:
         manager_class._built_with_as_manager = True
@@ -59,7 +94,6 @@ class TreeQuerySet(models.QuerySet):
         return manager_class()
 
     as_manager.queryset_only = True
-    as_manager = classmethod(as_manager)
 
     def ancestors(self, of, *, include_self=False):
         """
@@ -94,10 +128,7 @@ class TreeQuerySet(models.QuerySet):
                 where=[
                     # XXX This *may* be unsafe with some primary key field types.
                     # It is certainly safe with integers.
-                    'instr(__tree.tree_path, "{sep}{pk}{sep}") <> 0'.format(
-                        pk=self.model._meta.pk.get_db_prep_value(pk(of), connection),
-                        sep=SEPARATOR,
-                    )
+                    f'instr(__tree.tree_path, "{SEPARATOR}{self.model._meta.pk.get_db_prep_value(pk(of), connection)}{SEPARATOR}") <> 0'
                 ]
             )
 
